"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk = tslib_1.__importStar(require("chalk"));
const debug_1 = tslib_1.__importDefault(require("debug"));
const fs = tslib_1.__importStar(require("fs"));
const yargs_1 = tslib_1.__importDefault(require("yargs"));
const CleanCommandModule_1 = require("./commands/CleanCommandModule");
const CreateCommandModule_1 = require("./commands/CreateCommandModule");
const EntrypointCommandModule_1 = require("./commands/EntrypointCommandModule");
const InitCommandModule_1 = require("./commands/InitCommandModule");
const configure_1 = require("./options/configure");
const options_1 = require("./options/options");
const log = debug_1.default('cti:cti-cli');
const version = '1.10.2';
function setter(name, yargv) {
    const option = options_1.options.get(name);
    if (option !== undefined && option !== null) {
        yargv.option(name, option);
    }
}
const argv = yargs_1.default
    .command({
    aliases: '$0 [cwds...]',
    builder: (args) => {
        setter('filefirst', args);
        setter('addnewline', args);
        setter('usesemicolon', args);
        setter('includecwd', args);
        setter('usetimestamp', args);
        setter('excludes', args);
        setter('fileexcludes', args);
        setter('targetexts', args);
        setter('verbose', args);
        setter('quote', args);
        setter('withoutcomment', args);
        setter('withoutbackup', args);
        setter('output', args);
        const anyArgs = args;
        return anyArgs;
    },
    command: 'create [cwds...]',
    describe: 'create index.ts file in working directory',
    handler: (args) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const workingDir = process.cwd();
        if (!args.cwds) {
            console.log(chalk.default.magenta('Enter working directory, '));
            console.log(chalk.default.red('cti [working directory]'));
            process.exit(1);
        }
        const targetDirs = Array.isArray(args.cwds) ? args.cwds : [args.cwds];
        yield Promise.all(targetDirs
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const createCommand = new CreateCommandModule_1.CreateCommandModule();
            const optionsFromCli = configure_1.createFromCli(args, cwd);
            return createCommand.do(workingDir, optionsFromCli);
        }));
    }),
})
    .command({
    builder: (args) => {
        setter('addnewline', args);
        setter('usesemicolon', args);
        setter('includecwd', args);
        setter('usetimestamp', args);
        setter('excludes', args);
        setter('fileexcludes', args);
        setter('targetexts', args);
        setter('verbose', args);
        setter('quote', args);
        setter('withoutcomment', args);
        setter('withoutbackup', args);
        setter('output', args);
        const anyArgs = args;
        return anyArgs;
    },
    command: 'entrypoint [cwds...]',
    describe: 'create entrypoint.ts file in working directory',
    handler: (args) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const workingDir = process.cwd();
        if (!args.cwds) {
            console.log(chalk.default.magenta('Enter working directory, '));
            console.log(chalk.default.red('cti [working directory]'));
            process.exit(1);
        }
        const targetDirs = Array.isArray(args.cwds) ? args.cwds : [args.cwds];
        yield Promise.all(targetDirs
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const entrypointCommand = new EntrypointCommandModule_1.EntrypointCommandModule();
            const optionsFromCli = configure_1.createFromCli(args, cwd, 'entrypoint.ts');
            return entrypointCommand.do(workingDir, optionsFromCli);
        }));
    }),
})
    .command({
    builder: (args) => {
        setter('addnewline', args);
        setter('usetimestamp', args);
        setter('verbose', args);
        const anyArgs = args;
        return anyArgs;
    },
    command: 'init [cwds...]',
    describe: 'create .ctirc file in working directory',
    handler: (args) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const workingDir = process.cwd();
        if (!args.cwds) {
            console.log(chalk.default.magenta('Enter working directory, '));
            console.log(chalk.default.red('cti [working directory]'));
            process.exit(1);
        }
        const targetDirs = Array.isArray(args.cwds) ? args.cwds : [args.cwds];
        yield Promise.all(targetDirs
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const initCommandModule = new InitCommandModule_1.InitCommandModule();
            const optionsFromCli = configure_1.createFromCli(args, cwd);
            return initCommandModule.do(workingDir, optionsFromCli);
        }));
    }),
})
    .command({
    builder: (args) => {
        setter('verbose', args);
        setter('output', args);
        const anyArgs = args;
        return anyArgs;
    },
    command: 'clean [cwds...]',
    describe: 'clean index.ts or entrypoint.ts file in working directory',
    handler: (args) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const workDir = process.cwd();
        if (!args.cwds) {
            console.log(chalk.default.magenta('Enter working directory, '));
            console.log(chalk.default.red('cti [working directory]'));
            process.exit(1);
        }
        const targetDirs = Array.isArray(args.cwds) ? args.cwds : [args.cwds];
        yield Promise.all(targetDirs
            .filter((cwd) => fs.existsSync(cwd))
            .map((cwd) => {
            const cleanCommand = new CleanCommandModule_1.CleanCommandModule();
            const optionsFromCli = configure_1.createFromCli(args, cwd);
            return cleanCommand.do(workDir, optionsFromCli);
        }));
    }),
})
    .version(version, 'version', 'display version information')
    .help().argv;
log('output filename: ', argv.output);
//# sourceMappingURL=cti.js.map